@@ -237,9 +237,9 @@ class TheBlockchainAPIResource:
 
     def transfer(
         self,
-        token_address: str,
-        recipient_address: str,
         secret_recovery_phrase: str,
+        recipient_address: str,
+        token_address: Optional[str] = None,
         derivation_path: Optional[str] = None,
         passphrase: str = str(),
         network: SolanaNetwork = SolanaNetwork.DEVNET,
@@ -247,9 +247,9 @@ class TheBlockchainAPIResource:
     ) -> str:
         """
         More info: https://docs.theblockchainapi.com/#tag/Solana-Wallet/paths/~1v1~1solana~1wallet~1transfer/post
-        :param token_address:
-        :param recipient_address:
         :param secret_recovery_phrase:
+        :param recipient_address:
+        :param token_address: If not provided, defaults to transferring SOL
         :param derivation_path: Derivation path default matches the CLI. Use "m/44/501/0/0" to match Phantom.
         :param passphrase:
         :param network:
@@ -257,7 +257,6 @@ class TheBlockchainAPIResource:
         :return:
         """
         payload = {
-            "token_address": token_address,
             "recipient_address": recipient_address,
             "secret_recovery_phrase": secret_recovery_phrase,
             "passphrase": passphrase,
@@ -266,6 +265,8 @@ class TheBlockchainAPIResource:
         }
         if derivation_path is not None:
             payload['derivation_path'] = derivation_path
+        if token_address is not None:
+            payload["token_address"] = token_address
 
         response = self._request(
             payload=payload,
@@ -315,7 +316,7 @@ class TheBlockchainAPIResource:
             "nft_description": nft_description,
             "nft_url": nft_url,
             "nft_metadata": nft_metadata,
-            "nft_upload_method": nft_upload_method
+            "nft_upload_method": nft_upload_method.value
         }
         if derivation_path is not None:
             payload['derivation_path'] = derivation_path
